﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using MediaLibraryPickerFirstImage.Models;
using Orchard;
using Orchard.Blogs.Models;
using Orchard.Blogs.Services;
using Orchard.ContentManagement;
using Orchard.ContentManagement.Drivers;
using Orchard.ContentManagement.Records;
using Orchard.MediaLibrary.Fields;
using Orchard.MediaLibrary.Models;
using Orchard.MediaLibrary.Services;

namespace MediaLibraryPickerFirstImage.Drivers
{
    public class MlibFirstImageDrivers : ContentPartDriver<MlibFirstImagePart>
    {
        private readonly IOrchardServices _services;
        private readonly IContentManager _contentManager;
        private readonly IBlogPostService _blogPostService;
        private readonly IMediaLibraryService _mediaLibraryService;
        public MlibFirstImageDrivers(IOrchardServices services, IContentManager contentManager, IBlogPostService blogPostService, IMediaLibraryService mediaLibraryService)
        {
            _services = services;
            _contentManager = contentManager;
            _blogPostService = blogPostService;
            _mediaLibraryService = mediaLibraryService;
        }
        protected override DriverResult Display(MlibFirstImagePart part, string displayType, dynamic shapeHelper)
        {
            var model = BuildMlibFirstImageViewModel(part);
            if (model == null)
            {
                return null;
            }
            return ContentShape("Parts_MlibFirstImage",
                                () =>
                                {
                                    var shape = shapeHelper.Parts_MlibFirstImage(ViewModel: model,
                                      Prefix: Prefix);
                                    return shape;
                                });
        } 
        private object BuildMlibFirstImageViewModel(MlibFirstImagePart part)
        {
            MediaPart mediaPart = new MediaPart();
            var partMedia = _contentManager.Get(part.Id).Parts.Where(m => m.Get(typeof(MediaLibraryPickerField), "MediaLibrary") != null).FirstOrDefault();
            if (partMedia == null)
            {
                return null;
            }
            var fieldMedia = partMedia.Fields.Where(m => m.Name == "MediaLibrary").FirstOrDefault();
            if (fieldMedia != null)
            {
                mediaPart = ((MediaLibraryPickerField)(fieldMedia)).MediaParts.FirstOrDefault();
            }
            return mediaPart;
        }
    }
}